@@ -1,4 +1,4 @@
-from __future__ import division
+from __future__ import division, print_function
 import numpy as np
 from scipy.stats import nanmean, nanmedian
 from scipy.io import loadmat, savemat
@@ -116,8 +116,6 @@ def icoshift(xT,  xP,  inter='whole',  n='f',  options=[1,  1,  0,  0,  0],  Sca
     # blocks of 32MB
     BLOCKSIZE = 2 ** 25
 
-    print xP.shape
-
     if len(Scal) != max(Scal.shape):
         error('Scal must be a vector')
     if max(Scal.shape) != xP.shape[1]:
@@ -168,13 +166,6 @@ def icoshift(xT,  xP,  inter='whole',  n='f',  options=[1,  1,  0,  0,  0],  Sca
             error(
                 'ERROR: number of intervals "inter" must be smaller than number of variables in xP')
 
-    options = np.array(options)
-    options_co = np.array([1, 1, 0, 0, 0]).reshape(1, -1)
-
-    if max(options.shape) < max(options_co.shape):
-        options[(end + 1 - 1):max(options_co.shape)
-                ] = options_co[(max(options.shape) + 1 - 1):]
-
     if options[0] < 0 or options[0] > 2:
         error('options(1) must be 0, 1 or 2')
 
@@ -536,7 +527,7 @@ def coshifta(xT, xP, refW=np.array([0]), n=np.array([1, 2, 3]), options=np.array
     else:
         nR, mR = refW.shape[0], 0
 
-    print 'mT,mP', mT, mP
+    print('mT,mP', mT, mP)
 
     if (mT != mP):
         error(
@@ -704,8 +695,8 @@ def defints(xP, interv, opt):
 
 
 def CC_FFTShift(T, X=False, options=np.array([])):
-    dimX = X.shape
-    dimT = T.shape
+    dimX = np.array( X.shape )
+    dimT = np.array( T.shape )
 
     # .reshape(1,-1)
     optionsDefault = np.array(
@@ -717,6 +708,7 @@ def CC_FFTShift(T, X=False, options=np.array([])):
         options[o:] = optionsDefault[o:]
 
     options[np.isnan(options)] = optionsDefault[np.isnan(options)]
+    print(options)
 
     if options[0] > options[1]:
         error('Lower bound for shift is larger than upper bound')
@@ -1258,12 +1250,12 @@ def dscal2dpts(*varargin):
 
 
 def warning(msg):
-    print msg
+    print(msg)
     return True
 
 
 def error(msg):
-    print msg
+    print(msg)
     return False
 
 
